==> hscan-3.2.4.tar.gz: hscan-3.2.4/scan/downloade/aiohttp_downloader.py <==
import random
import asyncio
import aiohttp
from aiohttp import ClientTimeout

from scan.response import Response
from scan.common import logger


class Downloader:
    def __init__(self):
        self.session = None

    @staticmethod
    async def gen_headers():
        kit = f'{random.randint(490, 540)}.{random.randint(10, 90)}'
        return {
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;'
                      'q=0.8,application/signed-exchange;v=b3;q=0.9',
            'Accept-Encoding': 'gzip, deflate, br',
            'Accept-Language': 'en;q=0.9',
            'User-Agent': f'Mozilla/5.0 (Macintosh; Intel Mac OS X {random.randint(6, 15)}_{random.randint(2, 20)}'
                          f'_{random.randint(1, 9)}) AppleWebKit/{kit} (KHTML, like Gecko) '
                          f'Chrome/{random.randint(95, 98)}.0.{random.randint(1000, 5000)}.{random.randint(100, 200)}'
                          f' Safari/{kit}'
        }

    @staticmethod
    async def log_response(response):
        request = response.request_info
        if response.status not in [200, 301, 302]:
            logger.warning(f'{response.status}  {request.url}')
        else:
            logger.info(f'{response.status}  {request.url}')

    async def request(self, url, params=None, headers=None, cookies=None, auth=None, proxies=None, allow_redirects=True,
                      verify=True, http2=False, content=None, data=None, files=None, json=None, stream=False,
                      timeout=30, cycle=3, tls=False, session=True):
        if not self.session:
            async with asyncio.Lock():
                self.session = aiohttp.ClientSession(timeout=ClientTimeout(timeout))
        if data or json or content:
            method = 'POST'
        else:
            method = 'GET'
        if not headers:
            headers = await self.gen_headers()
        if proxies and isinstance(proxies, dict):
            proxies = list(proxies.values())[0]
        response = Response()
        response.request_url = url
        for _ in range(cycle):
            try:
                resp = await self.session.request(method=method, url=url, data=data, json=json, params=params,
                                                  headers=headers, cookies=cookies, proxy=proxies, auth=auth,
                                                  allow_redirects=allow_redirects)
                await self.log_response(resp)
                content = await resp.read()
                resp.__setattr__('status_code', resp.status)
                resp.__setattr__('content', content)
                response.response = resp
                return response
            except Exception as e:
                response.message = e
                logger.error(f'Failed to request {url}  {e}')
        return response

==> hscan-4.0.2.tar.gz: hscan-4.0.2/scan/downloade/aiohttp_downloader.py <==
import random
import asyncio
import aiohttp
from aiohttp import ClientTimeout

from scan.response import Response
from scan.common import logger


class Downloader:
    def __init__(self):
        self.session = None

    @staticmethod
    async def gen_headers():
        kit = f'{random.randint(490, 540)}.{random.randint(10, 90)}'
        return {
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;'
                      'q=0.8,application/signed-exchange;v=b3;q=0.9',
            'Accept-Encoding': 'gzip, deflate, br',
            'Accept-Language': 'en;q=0.9',
            'User-Agent': f'Mozilla/5.0 (Macintosh; Intel Mac OS X {random.randint(6, 15)}_{random.randint(2, 20)}'
                          f'_{random.randint(1, 9)}) AppleWebKit/{kit} (KHTML, like Gecko) '
                          f'Chrome/{random.randint(95, 98)}.0.{random.randint(1000, 5000)}.{random.randint(100, 200)}'
                          f' Safari/{kit}'
        }

    @staticmethod
    async def log_response(response):
        request = response.request_info
        if response.status not in [200, 301, 302]:
            logger.warning(f'{response.status}  {request.url}')
        else:
            logger.debug(f'{response.status}  {request.url}')

    async def request(self, url, params=None, headers=None, cookies=None, auth=None, proxies=None, allow_redirects=True,
                      verify=True, http2=False, content=None, data=None, files=None, json=None, stream=False,
                      timeout=30, cycle=3, tls=False, session=True):
        if not self.session:
            async with asyncio.Lock():
                self.session = aiohttp.ClientSession(timeout=ClientTimeout(timeout))
        if data or json or content:
            method = 'POST'
        else:
            method = 'GET'
        if not headers:
            headers = await self.gen_headers()
        if proxies and isinstance(proxies, dict):
            proxies = list(proxies.values())[0]
        response = Response()
        response.request_url = url
        for _ in range(cycle):
            try:
                resp = await self.session.request(method=method, url=url, data=data, json=json, params=params,
                                                  headers=headers, cookies=cookies, proxy=proxies, auth=auth,
                                                  allow_redirects=allow_redirects)
                await self.log_response(resp)
                content = await resp.read()
                resp.__setattr__('status_code', resp.status)
                resp.__setattr__('content', content)
                response.response = resp
                return response
            except Exception as e:
                response.message = e
                logger.error(f'Failed to request {url}  {e}')
        return response
